==> magento-quality-patches-1.1.51.zip: src/Test/Functional/Acceptance/B2Bx244x245Cest.php <==
<?php
/**
 * © Copyright 2013-present Adobe. All rights reserved.
 *
 * This file is licensed under OSL 3.0 or your existing commercial license or subscription
 * agreement with Magento or its Affiliates (the "Agreement).
 *
 * You may obtain a copy of the OSL 3.0 license at http://opensource.org/licenses/osl-3.0.php Open
 * Software License (OSL 3.0) or by contacting engcom@adobe.com for a copy.
 *
 * Subject to your payment of fees and compliance with the terms and conditions of the Agreement,
 * the Agreement supersedes the OSL 3.0 license with respect to this file.
 */
declare(strict_types=1);

namespace Magento\QualityPatches\Test\Functional\Acceptance;

/**
 * @group php81
 */
class B2Bx244X245Cest extends AbstractCest
{
    /**
     * @return array
     */
    protected function patchesDataProvider(): array
    {
        return [
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p1'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p2'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p3'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p4'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p5'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p6'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p7'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p8'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p9'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p10'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p1'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p2'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p3'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p4'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p5'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p6'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p7'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p8'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p9'],
        ];
    }
}

==> magento-quality-patches-1.1.59.zip: src/Test/Functional/Acceptance/B2Bx244x245Cest.php <==
<?php
/**
 * © Copyright 2013-present Adobe. All rights reserved.
 *
 * This file is licensed under OSL 3.0 or your existing commercial license or subscription
 * agreement with Magento or its Affiliates (the "Agreement).
 *
 * You may obtain a copy of the OSL 3.0 license at http://opensource.org/licenses/osl-3.0.php Open
 * Software License (OSL 3.0) or by contacting engcom@adobe.com for a copy.
 *
 * Subject to your payment of fees and compliance with the terms and conditions of the Agreement,
 * the Agreement supersedes the OSL 3.0 license with respect to this file.
 */
declare(strict_types=1);

namespace Magento\QualityPatches\Test\Functional\Acceptance;

/**
 * @group php81
 */
class B2Bx244X245Cest extends AbstractCest
{
    /**
     * @return array
     */
    protected function patchesDataProvider(): array
    {
        return [
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p1'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p2'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p3'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p4'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p5'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p6'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p7'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p8'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p9'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p10'],
            ['templateVersion' => '2.4.4-p1-p8', 'magentoVersion' => '2.4.4-p11'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p1'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p2'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p3'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p4'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p5'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p6'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p7'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p8'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p9'],
            ['templateVersion' => '2.4.5-p1-p7', 'magentoVersion' => '2.4.5-p10'],
        ];
    }
}
